@@ -49,6 +49,10 @@ class KID3_CORE_EXPORT FormatConfig : public GeneralConfig
   Q_PROPERTY(int caseConversion READ caseConversion WRITE setCaseConversionInt NOTIFY caseConversionChanged)
   /** name of locale to use for string conversions */
   Q_PROPERTY(QString localeName READ localeName WRITE setLocaleName NOTIFY localeNameChanged)
+  /** maximum length */
+  Q_PROPERTY(int maximumLength READ maximumLength WRITE setMaximumLength NOTIFY maximumLengthChanged)
+  /** true to enable length restriction */
+  Q_PROPERTY(bool enableMaximumLength READ enableMaximumLength WRITE setEnableMaximumLength NOTIFY enableMaximumLengthChanged)
   /** true to enable formating in line edits */
   Q_PROPERTY(bool formatWhileEditing READ formatWhileEditing WRITE setFormatWhileEditing NOTIFY formatWhileEditingChanged)
   /** true if string replacement enabled */
@@ -93,6 +97,18 @@ public:
    */
   void formatString(QString& str) const;
 
+  /**
+   * Join base name and extension respecting maximum length.
+   *
+   * Truncation to maximumLength() is only done if enableMaximumLength() and
+   * setAsFilenameFormatter() are set.
+   *
+   * @param baseName file name without extension
+   * @param extension file name extension starting with dot
+   * @return file name with extension, eventually truncated to maximum length.
+   */
+  QString joinFileName(const QString& baseName, const QString& extension) const;
+
   /**
    * Format frames using this configuration.
    *
@@ -169,6 +185,18 @@ public:
   /** Set if data validation is enabled. */
   void setEnableValidation(bool enableValidation);
 
+  /** Check if length restriction is enabled. */
+  bool enableMaximumLength() const { return m_enableMaximumLength; }
+
+  /** Set if length restriction is enabled. */
+  void setEnableMaximumLength(bool enableMaximumLength);
+
+  /** Get maximum length. */
+  int maximumLength() const { return m_maximumLength; }
+
+  /** Set maximum length. */
+  void setMaximumLength(int maximumLength);
+
   /**
    * String list of case conversion names.
    */
@@ -198,6 +226,12 @@ signals:
   /** Emitted when @a enableValidation changed. */
   void enableValidationChanged(bool enableValidation);
 
+  /** Emitted when @a enableMaximumLength changed. */
+  void enableMaximumLengthChanged(bool enableMaximumLength);
+
+  /** Emitted when @a maximumLength changed. */
+  void maximumLengthChanged(int maximumLength);
+
 private:
   /** Returns a lowercase copy of @a str. */
   QString toLower(const QString& str) const;
@@ -214,6 +248,8 @@ private:
   QString m_localeName;
   /** Locale to use for string conversions */
   const QLocale* m_locale;
+  int m_maximumLength;
+  bool m_enableMaximumLength;
   /** true if it is a file formatter */
   bool m_filenameFormatter;
   bool m_formatWhileEditing;
