@@ -33,6 +33,8 @@
 #include <QStringList>
 #include <QTextCursor>
 #include "taggedfile.h"
+#include "iusercommandprocessor.h"
+#include "kid3application.h"
 
 /**
  * Constructor.
@@ -124,12 +126,19 @@ void ExternalProcess::OutputViewer::scrollToBottom()
 /**
  * Constructor.
  *
+ * @param app application context
  * @param parent parent object
  */
-ExternalProcess::ExternalProcess(QWidget* parent) :
-  QObject(parent), m_parent(parent), m_process(0), m_outputViewer(0)
+ExternalProcess::ExternalProcess(Kid3Application* app, QWidget* parent) :
+  QObject(parent), m_app(app), m_parent(parent), m_process(0), m_outputViewer(0)
 {
   setObjectName(QLatin1String("ExternalProcess"));
+  foreach (IUserCommandProcessor* userCommandProcessor,
+           m_app->getUserCommandProcessors()) {
+    userCommandProcessor->initialize(m_app);
+    connect(userCommandProcessor->qobject(), SIGNAL(commandOutput(QString)),
+            this, SLOT(showOutputLine(QString)));
+  }
 }
 
 /**
@@ -137,6 +146,13 @@ ExternalProcess::ExternalProcess(QWidget* parent) :
  */
 ExternalProcess::~ExternalProcess()
 {
+  foreach (IUserCommandProcessor* userCommandProcessor,
+           m_app->getUserCommandProcessors()) {
+    userCommandProcessor->cleanup();
+  }
+  if (m_outputViewer) {
+    m_outputViewer->close();
+  }
   delete m_outputViewer;
 }
 
@@ -185,6 +201,15 @@ void ExternalProcess::launchCommand(const QString& name, const QStringList& args
 
   QStringList arguments = args;
   QString program = arguments.takeFirst();
+  if (program.startsWith(QLatin1Char('@'))) {
+    program = program.mid(1);
+    foreach (IUserCommandProcessor* userCommandProcessor,
+             m_app->getUserCommandProcessors()) {
+      if (userCommandProcessor->userCommandKeys().contains(program) &&
+          userCommandProcessor->startUserCommand(program, arguments, showOutput))
+        return;
+    }
+  }
   m_process->start(program, arguments);
   if (!m_process->waitForStarted(10000)) {
     QMessageBox::warning(
@@ -201,3 +226,14 @@ void ExternalProcess::readFromStdout()
 {
   m_outputViewer->append(QString::fromLocal8Bit(m_process->readAllStandardOutput()));
 }
+
+/**
+ * Show a line in the output viewer.
+ * @param msg message to be displayed
+ */
+void ExternalProcess::showOutputLine(const QString& msg)
+{
+  if (m_outputViewer) {
+    m_outputViewer->append(msg + QLatin1Char('\n'));
+  }
+}
