@@ -478,6 +478,25 @@ public:
    */
   Q_INVOKABLE QString performRenameActions();
 
+  /**
+   * Reset the file system model and then try to perform the rename actions.
+   * On Windows, renaming directories fails when they have a subdirectory which
+   * is open in the file system model. This method can be used to retry in such
+   * a situation.
+   */
+  void tryRenameActionsAfterReset();
+
+  /**
+   * Reset the file system model and then try to rename a file.
+   * On Windows, renaming directories fails when they have a subdirectory which
+   * is open in the file system model. This method can be used to retry in such
+   * a situation.
+   *
+   * @param oldName old file name
+   * @param newName new file name
+   */
+  void tryRenameAfterReset(const QString& oldName, const QString& newName);
+
   /**
    * Set the directory name from the tags.
    * The directory must not have modified files.
@@ -1323,6 +1342,16 @@ private slots:
    */
   void scheduleNextRenameAction(const QPersistentModelIndex& index);
 
+  /**
+   * Perform rename actions after the file system model has been reset.
+   */
+  void performRenameActionsAfterReset();
+
+  /**
+   * Rename after the file system model has been reset.
+   */
+  void renameAfterReset();
+
   /**
    * Update selection and emit signals when directory is opened.
    */
@@ -1489,6 +1518,10 @@ private:
   QList<ImportTrackDataVector> m_batchImportAlbums;
   ImportTrackDataVector m_batchImportTrackDataList;
 
+  /* Context for renameAfterReset() */
+  QString m_renameAfterResetOldName;
+  QString m_renameAfterResetNewName;
+
   /* Context for editFrame() */
   TaggedFile* m_editFrameTaggedFile;
   QString m_editFrameName;
