@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 25 Aug 2007
  *
- * Copyright (C) 2007-2013  Urs Fleisch
+ * Copyright (C) 2007-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -134,7 +134,7 @@ const char* getNameFromType(Frame::Type type)
     QT_TRANSLATE_NOOP("@default", "Original Album"),  // FT_OriginalAlbum,
     QT_TRANSLATE_NOOP("@default", "Original Artist"), // FT_OriginalArtist,
     QT_TRANSLATE_NOOP("@default", "Original Date"),   // FT_OriginalDate,
-    QT_TRANSLATE_NOOP("@default", "Part"),            // FT_Part,
+    QT_TRANSLATE_NOOP("@default", "Disc Subtitle"),   // FT_Part,
     QT_TRANSLATE_NOOP("@default", "Performer"),       // FT_Performer,
     QT_TRANSLATE_NOOP("@default", "Picture"),         // FT_Picture,
     QT_TRANSLATE_NOOP("@default", "Publisher"),       // FT_Publisher,
@@ -149,8 +149,9 @@ const char* getNameFromType(Frame::Type type)
     QT_TRANSLATE_NOOP("@default", "Website"),         // FT_Website,
     QT_TRANSLATE_NOOP("@default", "WWW Audio File"),  // FT_WWWAudioFile,
     QT_TRANSLATE_NOOP("@default", "WWW Audio Source"), // FT_WWWAudioSource,
-    QT_TRANSLATE_NOOP("@default", "Release Date")     // FT_ReleaseDate,
-                                  // FT_LastFrame = FT_ReleaseDate
+    QT_TRANSLATE_NOOP("@default", "Release Date"),    // FT_ReleaseDate,
+    QT_TRANSLATE_NOOP("@default", "Rating")           // FT_Rating,
+                                  // FT_LastFrame = FT_Rating
   };
   struct not_used { int array_size_check[
       sizeof(names) / sizeof(names[0]) == Frame::FT_LastFrame + 1
@@ -253,7 +254,6 @@ QMap<QByteArray, QByteArray> getDisplayNamesOfIds()
     { "PRODUCTNUMBER", QT_TRANSLATE_NOOP("@default", "Product Number") },
     { "RECORDINGDATE", QT_TRANSLATE_NOOP("@default", "Recording Date") },
     { "REMIXEDBY", QT_TRANSLATE_NOOP("@default", "Remixer") },
-    { "Rating", QT_TRANSLATE_NOOP("@default", "Rating") },
     { "TOTALDISCS", QT_TRANSLATE_NOOP("@default", "Total Discs") },
     { "TOTALTRACKS", QT_TRANSLATE_NOOP("@default", "Total Tracks") },
     { "TRACKTOTAL", QT_TRANSLATE_NOOP("@default", "Total Tracks") },
@@ -286,7 +286,7 @@ QMap<QByteArray, QByteArray> getDisplayNamesOfIds()
     { "pgap", QT_TRANSLATE_NOOP("@default", "Gapless Playback") },
     { "plID", QT_TRANSLATE_NOOP("@default", "Album ID") },
     { "purd", QT_TRANSLATE_NOOP("@default", "Purchase Date") },
-    { "rtng", QT_TRANSLATE_NOOP("@default", "Rating") },
+    { "rtng", QT_TRANSLATE_NOOP("@default", "Rating/Advisory") },
     { "sfID", QT_TRANSLATE_NOOP("@default", "Country Code") },
     { "sosn", QT_TRANSLATE_NOOP("@default", "Sort Show") },
     { "stik", QT_TRANSLATE_NOOP("@default", "Media Type") },
@@ -302,6 +302,9 @@ QMap<QByteArray, QByteArray> getDisplayNamesOfIds()
     { "\251mvc", QT_TRANSLATE_NOOP("@default", "Movement Count") },
     { "shwm", QT_TRANSLATE_NOOP("@default", "Show Work & Movement") },
     { "ownr", QT_TRANSLATE_NOOP("@default", "Owner") },
+    { "purl", QT_TRANSLATE_NOOP("@default", "Podcast URL") },
+    { "egid", QT_TRANSLATE_NOOP("@default", "Podcast GUID") },
+    { "cmID", QT_TRANSLATE_NOOP("@default", "Composer ID") },
     { "xid ", QT_TRANSLATE_NOOP("@default", "XID") },
     { "IARL", QT_TRANSLATE_NOOP("@default", "Archival Location") },
     { "ICMS", QT_TRANSLATE_NOOP("@default", "Commissioned") },
@@ -1162,14 +1165,17 @@ FrameCollection::const_iterator FrameCollection::searchByName(
   QString ucName = name.toUpper().remove(QLatin1Char('/'));
   int len = ucName.length();
   for (it = begin(); it != end(); ++it) {
-    QString ucFrameName(it->getName().toUpper().remove(QLatin1Char('/')));
-    if (ucName == ucFrameName.leftRef(len)) {
-      break;
-    }
-    int nlPos = ucFrameName.indexOf(QLatin1Char('\n'));
-    if (nlPos > 0 && ucName == ucFrameName.midRef(nlPos + 1, len)) {
-      // Description in TXXX, WXXX, COMM, PRIV matches
-      break;
+    foreach (const QString& frameName,
+             QStringList() << it->getName() << it->getInternalName()) {
+      QString ucFrameName(frameName.toUpper().remove(QLatin1Char('/')));
+      if (ucName == ucFrameName.leftRef(len)) {
+        return it;
+      }
+      int nlPos = ucFrameName.indexOf(QLatin1Char('\n'));
+      if (nlPos > 0 && ucName == ucFrameName.midRef(nlPos + 1, len)) {
+        // Description in TXXX, WXXX, COMM, PRIV matches
+        return it;
+      }
     }
   }
   return it;
