@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2013  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -42,7 +42,9 @@
 #include <QStringListModel>
 #include <QStandardItemModel>
 #include "formatconfig.h"
-#include "formatbox.h"
+#include "filenameformatbox.h"
+#include "tagformatbox.h"
+#include "tablemodeledit.h"
 #include "tagconfig.h"
 #include "fileconfig.h"
 #include "useractionsconfig.h"
@@ -53,6 +55,7 @@
 #include "configtable.h"
 #include "commandstablemodel.h"
 #include "checkablestringlistmodel.h"
+#include "starratingmappingsmodel.h"
 #include "fileproxymodel.h"
 #include "contexthelp.h"
 #include "frame.h"
@@ -127,7 +130,8 @@ ConfigDialogPages::ConfigDialogPages(IPlatformTools* platformTools,
   m_loadLastOpenedFileCheckBox(0), m_preserveTimeCheckBox(0),
   m_markChangesCheckBox(0), m_coverFileNameLineEdit(0),
   m_nameFilterComboBox(0), m_includeFoldersLineEdit(0),
-  m_excludeFoldersLineEdit(0), m_fileTextEncodingComboBox(0),
+  m_excludeFoldersLineEdit(0), m_showHiddenFilesCheckBox(0),
+  m_fileTextEncodingComboBox(0),
   m_markTruncationsCheckBox(0), m_textEncodingV1ComboBox(0),
   m_totalNumTracksCheckBox(0), m_commentNameComboBox(0),
   m_pictureNameComboBox(0), m_markOversizedPicturesCheckBox(0),
@@ -136,8 +140,8 @@ ConfigDialogPages::ConfigDialogPages(IPlatformTools* platformTools,
   m_textEncodingComboBox(0), m_id3v2VersionComboBox(0),
   m_trackNumberDigitsSpinBox(0), m_fnFormatBox(0), m_tagFormatBox(0),
   m_onlyCustomGenresCheckBox(0), m_genresEditModel(0),
-  m_quickAccessTagsModel(0), m_trackNameComboBox(0),
-  m_playOnDoubleClickCheckBox(0),
+  m_quickAccessTagsModel(0), m_starRatingMappingsModel(0),
+  m_trackNameComboBox(0), m_playOnDoubleClickCheckBox(0),
   m_commandsTable(0), m_commandsTableModel(0), m_browserLineEdit(0),
   m_proxyCheckBox(0), m_proxyLineEdit(0), m_proxyAuthenticationCheckBox(0),
   m_proxyUserNameLineEdit(0), m_proxyPasswordLineEdit(0),
@@ -308,8 +312,14 @@ QWidget* ConfigDialogPages::createTagsPage()
   QWidget* tag1AndTag2Page = new QWidget;
   QVBoxLayout* tag1AndTag2Layout = new QVBoxLayout(tag1AndTag2Page);
   QString tagFormatTitle(tr("&Tag Format"));
-  m_tagFormatBox = new FormatBox(tagFormatTitle, tag1AndTag2Page);
+  m_tagFormatBox = new TagFormatBox(tagFormatTitle, tag1AndTag2Page);
+  QGroupBox* ratingGroupBox = new QGroupBox(tr("Rating"), tag1AndTag2Page);
+  QVBoxLayout* ratingLayout = new QVBoxLayout(ratingGroupBox);
+  m_starRatingMappingsModel = new StarRatingMappingsModel(ratingGroupBox);
+  TableModelEdit* ratingEdit = new TableModelEdit(m_starRatingMappingsModel);
+  ratingLayout->addWidget(ratingEdit);
   tag1AndTag2Layout->addWidget(m_tagFormatBox);
+  tag1AndTag2Layout->addWidget(ratingGroupBox);
 
   QTabWidget* tagsTabWidget = new QTabWidget;
   if (tagCfg.taggedFileFeatures() & TaggedFile::TF_ID3v11) {
@@ -391,6 +401,8 @@ QWidget* ConfigDialogPages::createFilesPage()
                                            fileListGroupBox);
   m_excludeFoldersLineEdit = new QLineEdit(fileListGroupBox);
   excludeFoldersLabel->setBuddy(m_excludeFoldersLineEdit);
+  m_showHiddenFilesCheckBox = new QCheckBox(tr("&Show hidden files"),
+                                            fileListGroupBox);
   QGridLayout* fileListGroupBoxLayout = new QGridLayout(fileListGroupBox);
   fileListGroupBoxLayout->addWidget(nameFilterLabel, 0, 0);
   fileListGroupBoxLayout->addWidget(m_nameFilterComboBox, 0, 1);
@@ -398,6 +410,7 @@ QWidget* ConfigDialogPages::createFilesPage()
   fileListGroupBoxLayout->addWidget(m_includeFoldersLineEdit, 1, 1);
   fileListGroupBoxLayout->addWidget(excludeFoldersLabel, 2, 0);
   fileListGroupBoxLayout->addWidget(m_excludeFoldersLineEdit, 2, 1);
+  fileListGroupBoxLayout->addWidget(m_showHiddenFilesCheckBox, 3, 0, 1, 2);
   rightLayout->addWidget(fileListGroupBox);
   rightLayout->addStretch();
 
@@ -406,8 +419,7 @@ QWidget* ConfigDialogPages::createFilesPage()
   vlayout->addLayout(hlayout);
 
   QString fnFormatTitle(tr("&Filename Format"));
-  m_fnFormatBox = new FormatBox(fnFormatTitle, filesPage);
-  m_fnFormatBox->hideValidationCheckBox();
+  m_fnFormatBox = new FilenameFormatBox(fnFormatTitle, filesPage);
   vlayout->addWidget(m_fnFormatBox);
   return filesPage;
 }
@@ -583,9 +595,11 @@ void ConfigDialogPages::setConfigs(
         folderPatternListToString(fileCfg.includeFolders(), true));
   m_excludeFoldersLineEdit->setText(
         folderPatternListToString(fileCfg.excludeFolders(), false));
+  m_showHiddenFilesCheckBox->setChecked(fileCfg.showHiddenFiles());
   m_fileTextEncodingComboBox->setCurrentIndex(fileCfg.textEncodingIndex());
   m_onlyCustomGenresCheckBox->setChecked(tagCfg.onlyCustomGenres());
   m_genresEditModel->setStringList(tagCfg.customGenres());
+  m_starRatingMappingsModel->setMappings(tagCfg.starRatingMappings());
   quint64 frameMask = tagCfg.quickAccessFrames();
   QList<int> frameTypes = tagCfg.quickAccessFrameOrder();
   if (frameTypes.size() != Frame::FT_LastFrame + 1) {
@@ -679,6 +693,12 @@ void ConfigDialogPages::setConfigs(
   }
   m_enabledPluginsModel->setStringList(importPlugins);
   m_enabledPluginsModel->setBitMask(importPluginsMask);
+
+  if (!guiCfg.configWindowGeometry().isEmpty()) {
+    if (QWidget* configDialog = qobject_cast<QWidget*>(parent())) {
+      configDialog->restoreGeometry(guiCfg.configWindowGeometry());
+    }
+  }
 }
 
 /**
@@ -713,9 +733,11 @@ void ConfigDialogPages::getConfig() const
         folderPatternListFromString(m_includeFoldersLineEdit->text(), true));
   fileCfg.setExcludeFolders(
         folderPatternListFromString(m_excludeFoldersLineEdit->text(), false));
+  fileCfg.setShowHiddenFiles(m_showHiddenFilesCheckBox->isChecked());
   fileCfg.setTextEncodingIndex(m_fileTextEncodingComboBox->currentIndex());
   tagCfg.setOnlyCustomGenres(m_onlyCustomGenresCheckBox->isChecked());
   tagCfg.setCustomGenres(m_genresEditModel->stringList());
+  tagCfg.setStarRatingMappings(m_starRatingMappingsModel->getMappings());
   QList<int> frameTypes;
   bool isStandardFrameOrder = true;
   quint64 frameMask = 0;
@@ -780,4 +802,8 @@ void ConfigDialogPages::getConfig() const
     }
   }
   importCfg.setDisabledPlugins(disabledPlugins);
+
+  if (QWidget* configDialog = qobject_cast<QWidget*>(parent())) {
+    guiCfg.setConfigWindowGeometry(configDialog->saveGeometry());
+  }
 }
