@@ -39,9 +39,8 @@ class ConfigTableModel;
 /**
  * Group box containing format options.
  */
-class FormatBox : public QGroupBox
-{
-Q_OBJECT
+class FormatBox : public QGroupBox {
+  Q_OBJECT
 public:
   /**
    * Constructor.
@@ -54,26 +53,21 @@ public:
   /**
    * Destructor.
    */
-  ~FormatBox();
-
-  /**
-   * Hide the validation check box.
-   */
-  void hideValidationCheckBox();
+  virtual ~FormatBox();
 
   /**
    * Set the values from a format configuration.
    *
    * @param cfg format configuration
    */
-  void fromFormatConfig(const FormatConfig& cfg);
+  virtual void fromFormatConfig(const FormatConfig& cfg);
 
   /**
    * Store the values in a format configuration.
    *
    * @param cfg format configuration
    */
-  void toFormatConfig(FormatConfig& cfg) const;
+  virtual void toFormatConfig(FormatConfig& cfg) const;
 
 private:
   QComboBox* m_caseConvComboBox;
@@ -84,7 +78,6 @@ private:
   ConfigTable* m_strReplTable;
   ConfigTableModel* m_strReplTableModel;
   QCheckBox* m_formatEditingCheckBox;
-  QCheckBox* m_validationCheckBox;
 };
 
 #endif
