@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2013  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -873,7 +873,7 @@ static const struct TypeStrOfId {
   { Frame::FT_Other,          QT_TRANSLATE_NOOP("@default", "OWNE - Ownership frame") },                                 /* OWNE */
   { Frame::FT_Other,          QT_TRANSLATE_NOOP("@default", "PRIV - Private frame") },                                   /* PRIV */
   { Frame::FT_Other,          QT_TRANSLATE_NOOP("@default", "PCNT - Play counter") },                                    /* PCNT */
-  { Frame::FT_Other,          QT_TRANSLATE_NOOP("@default", "POPM - Popularimeter") },                                   /* POPM */
+  { Frame::FT_Rating,         QT_TRANSLATE_NOOP("@default", "POPM - Popularimeter") },                                   /* POPM */
   { Frame::FT_Other,          QT_TRANSLATE_NOOP("@default", "POSS - Position synchronisation frame") },                  /* POSS */
   { Frame::FT_Other,          QT_TRANSLATE_NOOP("@default", "RBUF - Recommended buffer size") },                         /* RBUF */
   { Frame::FT_Other,          0 },                                                                                       /* RVA2 */
@@ -1830,6 +1830,11 @@ ID3_Frame* Mp3File::createId3FrameFromFrame(Frame& frame) const
       if (fld) {
         setString(fld, QLatin1String("eng"));
       }
+    } else if (id == ID3FID_POPULARIMETER) {
+      fld = id3Frame->GetField(ID3FN_EMAIL);
+      if (fld) {
+        setString(fld, TagConfig::instance().defaultPopmEmail());
+      }
     }
     if (!frame.fieldList().empty()) {
       setId3v2Frame(id3Frame, frame);
