@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 25 Oct 2007
  *
- * Copyright (C) 2007-2013  Urs Fleisch
+ * Copyright (C) 2007-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -134,6 +134,10 @@ static const struct {
   { "atID", Frame::FT_Other },
   { "plID", Frame::FT_Other },
   { "geID", Frame::FT_Other },
+  { "purl", Frame::FT_Other },
+  { "egid", Frame::FT_Other },
+  { "cmID", Frame::FT_Other },
+  { "xid ", Frame::FT_Other },
 #endif
   { "covr", Frame::FT_Picture }
 },
@@ -173,7 +177,8 @@ freeFormNameTypes[] = {
   { "WEBSITE", Frame::FT_Website },
   { "WWWAUDIOFILE", Frame::FT_WWWAudioFile },
   { "WWWAUDIOSOURCE", Frame::FT_WWWAudioSource },
-  { "RELEASEDATE", Frame::FT_ReleaseDate }
+  { "RELEASEDATE", Frame::FT_ReleaseDate },
+  { "rate", Frame::FT_Rating }
 };
 
 /**
@@ -339,14 +344,10 @@ static QByteArray getValueByteArray(const char* name,
     }
 #endif
 #if MPEG4IP_MAJOR_MINOR_VERSION >= 0x0109
-  } else if (std::strcmp(name, "tvsn") == 0) {
-    if (size >= 4) {
-      uint val = value[3] + (value[2] << 8) + (value[1] << 16) + (value[0] << 24);
-      if (val > 0) {
-        str.setNum(val);
-      }
-    }
-  } else if (std::strcmp(name, "tves") == 0) {
+  } else if (std::strcmp(name, "tvsn") == 0 || std::strcmp(name, "tves") == 0 ||
+             std::strcmp(name, "sfID") == 0 || std::strcmp(name, "cnID") == 0 ||
+             std::strcmp(name, "atID") == 0 || std::strcmp(name, "geID") == 0 ||
+             std::strcmp(name, "cmID") == 0) {
     if (size >= 4) {
       uint val = value[3] + (value[2] << 8) +
         (value[1] << 16) + (value[0] << 24);
@@ -354,50 +355,12 @@ static QByteArray getValueByteArray(const char* name,
         str.setNum(val);
       }
     }
-  } else if (std::strcmp(name, "pcst") == 0) {
+  } else if (std::strcmp(name, "pcst") == 0 || std::strcmp(name, "hdvd") == 0 ||
+             std::strcmp(name, "stik") == 0 || std::strcmp(name, "rtng") == 0 ||
+             std::strcmp(name, "akID") == 0) {
     if (size >= 1) {
       str.setNum(value[0]);
     }
-  } else if (std::strcmp(name, "hdvd") == 0) {
-    if (size >= 1) {
-      str.setNum(value[0]);
-    }
-  } else if (std::strcmp(name, "stik") == 0) {
-    if (size >= 1) {
-      str.setNum(value[0]);
-    }
-  } else if (std::strcmp(name, "rtng") == 0) {
-    if (size >= 1) {
-      str.setNum(value[0]);
-    }
-  } else if (std::strcmp(name, "akID") == 0) {
-    if (size >= 1) {
-      str.setNum(value[0]);
-    }
-  } else if (std::strcmp(name, "sfID") == 0) {
-    if (size >= 4) {
-      uint val = value[3] + (value[2] << 8) +
-        (value[1] << 16) + (value[0] << 24);
-      if (val > 0) {
-        str.setNum(val);
-      }
-    }
-  } else if (std::strcmp(name, "cnID") == 0) {
-    if (size >= 4) {
-      uint val = value[3] + (value[2] << 8) +
-        (value[1] << 16) + (value[0] << 24);
-      if (val > 0) {
-        str.setNum(val);
-      }
-    }
-  } else if (std::strcmp(name, "atID") == 0) {
-    if (size >= 4) {
-      uint val = value[3] + (value[2] << 8) +
-        (value[1] << 16) + (value[0] << 24);
-      if (val > 0) {
-        str.setNum(val);
-      }
-    }
   } else if (std::strcmp(name, "plID") == 0) {
     if (size >= 8) {
       qulonglong val = (qulonglong)value[7] + ((qulonglong)value[6] << 8) +
@@ -408,14 +371,6 @@ static QByteArray getValueByteArray(const char* name,
         str.setNum(val);
       }
     }
-  } else if (std::strcmp(name, "geID") == 0) {
-    if (size >= 4) {
-      uint val = value[3] + (value[2] << 8) +
-        (value[1] << 16) + (value[0] << 24);
-      if (val > 0) {
-        str.setNum(val);
-      }
-    }
 #endif
   } else {
     str = QByteArray(reinterpret_cast<const char*>(value), size);
@@ -757,10 +712,23 @@ bool M4aFile::writeTags(bool force, bool* renamed, bool preserve)
           } else if (name == QLatin1String("geID")) {
             uint32_t val = str.toULong();
             MP4TagsSetGenreID(tags, &val);
+          } else if (name == QLatin1String("cmID")) {
+            uint32_t val = str.toULong();
+            MP4TagsSetComposerID(tags, &val);
+          } else if (name == QLatin1String("xid ")) {
+            MP4TagsSetXID(tags, str);
           } else {
-            MP4ItmfItem* item = MP4ItmfItemAlloc("----", 1);
-            item->mean = strdup("com.apple.iTunes");
-            item->name = strdup(name.toUtf8().data());
+            MP4ItmfItem* item;
+            if (name.length() == 4 &&
+                (name.at(0).toLatin1() == '\251' ||
+                 (name.at(0) >= QLatin1Char('a') &&
+                  name.at(0) <= QLatin1Char('z')))) {
+              item = MP4ItmfItemAlloc(name.toLatin1().constData(), 1);
+            } else {
+              item = MP4ItmfItemAlloc("----", 1);
+              item->mean = strdup("com.apple.iTunes");
+              item->name = strdup(name.toUtf8().data());
+            }
 
             MP4ItmfData& data = item->dataList.elements[0];
             data.typeCode = MP4_ITMF_BT_UTF8;
@@ -1313,7 +1281,8 @@ QStringList M4aFile::getFrameIds(Frame::TagNumber tagNr) const
 #if MPEG4IP_MAJOR_MINOR_VERSION >= 0x0109
     Frame::FT_Lyrics,
 #endif
-    Frame::FT_Picture
+    Frame::FT_Picture,
+    Frame::FT_Rating
 #if MPEG4IP_MAJOR_MINOR_VERSION >= 0x0109
     , Frame::FT_SortAlbum,
     Frame::FT_SortAlbumArtist,
@@ -1325,7 +1294,7 @@ QStringList M4aFile::getFrameIds(Frame::TagNumber tagNr) const
 
   QStringList lst;
   for (unsigned i = 0; i < sizeof(types) / sizeof(types[0]); ++i) {
-    lst.append(Frame::ExtendedType(static_cast<Frame::Type>(i), QLatin1String("")).
+    lst.append(Frame::ExtendedType(types[i], QLatin1String("")).
                getName());
   }
 #if MPEG4IP_MAJOR_MINOR_VERSION >= 0x0106
@@ -1336,7 +1305,8 @@ QStringList M4aFile::getFrameIds(Frame::TagNumber tagNr) const
     QLatin1String("geID") << QLatin1String("hdvd") << QLatin1String("keyw") << QLatin1String("ldes") << QLatin1String("pcst") <<
     QLatin1String("plID") << QLatin1String("purd") << QLatin1String("rtng") << QLatin1String("sfID") <<
     QLatin1String("sosn") << QLatin1String("stik") << QLatin1String("tven") <<
-    QLatin1String("tves") << QLatin1String("tvnn") << QLatin1String("tvsh") << QLatin1String("tvsn");
+    QLatin1String("tves") << QLatin1String("tvnn") << QLatin1String("tvsh") << QLatin1String("tvsn") <<
+    QLatin1String("purl") << QLatin1String("egid") << QLatin1String("cmID") << QLatin1String("xid ");
 #endif
   return lst;
 }
