@@ -312,14 +312,14 @@ class CliFunctionsTestCase(unittest.TestCase):
                 'File: MPEG 1 Layer 3 64 kbps 44100 Hz 1 Channels \n'
                 '  Name: test.mp3\n'
                 'Tag 2: ID3v2.3.0\n'
-                '* Popularimeter  5\n'
+                '* Rating        5\n'
                 '\n'
                 '5\n'
                 '0\n'
                 'File: MPEG 1 Layer 3 64 kbps 44100 Hz 1 Channels \n'
                 '  Name: test.mp3\n'
                 'Tag 2: ID3v2.3.0\n'
-                '* Popularimeter  4\n'
+                '* Rating        4\n'
                 'ufleisch@users.sourceforge.net\n'
                 '4\n'
                 '3\n'
